# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system

from winrt.windows.applicationmodel.datatransfer.dragdrop import DragDropModifiers

Self = typing.TypeVar('Self')

